library(ggplot2)
library(phytools)
library(geiger)
library(nlme)
library(ggpubr)

# read in summary data file
dat<-read.csv(file.choose())
rownames(dat)<-dat$Species
rownames(dat) <- gsub(" ", "_", rownames(dat))

#read tree
tree<-read.newick(file.choose())

dat1<-read.csv(file.choose())
colnames(dat1) <- c("species", "ID", "substrate", "orient", "trial", "HL", "mass", "SL", "SF", "speed", "dimSL", "dimSF", "dimSp")
speed1 <- dat1$SL*dat1$SF
dat1<-cbind(dat1, speed1)

#function computed sl and sf coefs from raw data file
byspeciesraw <- function (species1) {
  speed<-(subset.data.frame(dat1, subset=species==species1)$speed1)
  sl<-(subset.data.frame(dat1, subset=species==species1)$SL)
  sf<-(subset.data.frame(dat1, subset=species==species1)$SF)
  mod1<-lm((speed)~(sf))
  mod2<-lm((speed)~(sl))
  o<-summary(mod1)
  p<-summary(mod2)
  c(o$r.squared, p$r.squared, mod1$coefficients[2], mod2$coefficients[2], o$coefficients[8], p$coefficients[8])
}

unique(dat1$species) -> sp
out<-sapply(sp, byspeciesraw)
out <- as.data.frame(out)
colnames(out) <- sp
out <- t(out)
out <- as.data.frame(out)
rownames(out) <- gsub(" ", "_", rownames(out))
colnames(out) <- c("r2sf", "r2sl", "sfcoef", "slcoef", "psf", "psl")

de <- merge(dat, out, by="row.names", all=TRUE) 
rownames(de) <- de$Row.names
r2rat <- log(de$r2sf/de$r2sl)
de <- cbind(de, r2rat)

## SL ANALYSIS
mean(de$slcoef)
sd(de$slcoef)
mean(de$r2sl)
sd(de$r2sl)
table(de$psl<0.05)

#SL
modsl<-gls(slcoef~Individuals+Cycles+Substrate*log(Body.mass..kg.)+Posture*log(Body.mass..kg.), correlation=corPagel(1, tree, form = ~Species), data=de) 
summary(modsl)
anova(modsl, type="marginal")

c<-ggplot(de, aes(y =slcoef, x =log(Body.mass..kg.), color=Substrate)) +
  geom_point(alpha=0.5)+
  geom_smooth(method="lm")+ 
  theme_classic()+
  xlab("log Body Mass")+
  ylab("SL-Speed Slope")+
  theme(text=element_text(size=9))
d<-ggplot(de, aes(y =slcoef, x =log(Body.mass..kg.), color=Posture)) +
  geom_point(alpha=0.5)+
  geom_smooth(method="lm")+ 
  theme_classic()+
  xlab("log Body Mass")+
  ylab("SL-Speed Slope")+
  theme(text=element_text(size=9))+
  scale_color_manual(values=c("red", "black"))

#SF analysis
mean(de$sfcoef)
sd(de$sfcoef)
mean(de$r2sf)
sd(de$r2sf)
table(de$psf<0.05)

modsf<-gls(sfcoef~Individuals+Cycles+Substrate*log(Body.mass..kg.)+Posture*log(Body.mass..kg.), correlation=corPagel(1, tree, form = ~Species), data=de) 
summary(modsf)
anova(modsf, type="marginal")

a<-ggplot(de, aes(y =sfcoef, x =log(Body.mass..kg.), color=Substrate)) +
  geom_point(alpha=0.5)+
  geom_smooth(method="lm")+ 
  theme_classic()+
  xlab("log Body Mass")+
  ylab("SF-Speed Slope")+
  theme(text=element_text(size=9))
b<-ggplot(de, aes(y =sfcoef, x =log(Body.mass..kg.), color=Posture)) +
  geom_point(alpha=0.5)+
  geom_smooth(method="lm")+ 
  theme_classic()+
  xlab("log Body Mass")+
  ylab("SF-Speed Slope")+
  theme(text=element_text(size=9))+
  scale_color_manual(values=c("red", "black"))

aggregate(de$sfcoef~de$Substrate, FUN=mean)
aggregate(de$r2rat~de$Posture, FUN=sd)

#R2
mean(de$r2rat)
sd(de$r2rat)
table(de$r2rat<0)

modr2<-gls(r2rat~Individuals+Cycles+Substrate*log(Body.mass..kg.)+Posture*log(Body.mass..kg.), correlation=corPagel(1, tree, form = ~Species), data=de) 
summary(modr2)
anova(modr2, type="marginal")

aggregate(de$r2rat~de$Posture, FUN=mean)
aggregate(de$r2rat~de$Posture, FUN=sd)

e<-ggplot(de, aes(y =r2rat, x =log(Body.mass..kg.), color=Clade)) +
  geom_point(alpha=0.5)+
  geom_smooth(method="lm")+ 
  theme_classic()+
  xlab("log Body Mass")+
  ylab(expression(log~R^{"2"}~Ratio))+
  theme(text=element_text(size=9))
f<-ggplot(de, aes(y =r2rat, x =log(Body.mass..kg.), color=Posture)) +
  geom_point(alpha=0.5)+
  geom_smooth(method="lm")+ 
  theme_classic() +
  xlab("log Body Mass")+
  ylab(expression(log~R^{"2"}~Ratio))+
  theme(text=element_text(size=9))+
  scale_color_manual(values=c("red", "black"))

plots<-ggarrange(c,d,a,b,e,f, nrow=3, ncol=2, labels="AUTO")
ggsave('plot1.pdf', plots, height = 6, width = 10, units = "in")


# PRIMATE analyses
subset(de, de$Clade == "Mammal") -> de_mammal
tree_mam <- keep.tip(tree, row.names(de_mammal))
prim <- de_mammal$Primate
names(prim) <- de_mammal$Row.names
#SF
sfprim <- de_mammal$sfcoef
names(sfprim) <- de_mammal$Row.names
m<-gls(sfprim~prim, correlation=corPagel(1, tree_mam, form = ~Species), data=de_mammal)
anova(m)
summary(m)
#SL
de_mammal$slcoef -> slprim
names(slprim) <- de_mammal$Row.names
m<-gls(slprim~prim, correlation=corPagel(1, tree_mam, form = ~Species), data=de_mammal)
anova(m)
summary(m)
##r2
de_mammal$r2rat -> r2prim
names(r2prim) <- de_mammal$Row.names
m<-gls(r2prim~prim, correlation=corPagel(1, tree_mam, form = ~Species), data=de_mammal)
anova(m)
summary(m)
aggregate(de$sfcoef~de$Primate, FUN=mean)
aggregate(de$sfcoef~de$Primate, FUN=sd)
aggregate(de$slcoef~de$Primate, FUN=mean)
aggregate(de$slcoef~de$Primate, FUN=sd)
aggregate(de$r2rat~de$Primate, FUN=mean)
aggregate(de$r2rat~de$Primate, FUN=sd)

#CLADE analyses
#SF
m<-gls(sfcoef~Clade, correlation=corPagel(1, tree, form = ~Species), data=de)
anova(m)
summary(m)
n<-glht(m, linfct=mcp(Clade ="Tukey"))
summary(n)

#SL
m<-gls(slcoef~Clade, correlation=corPagel(1, tree, form = ~Species), data=de)
anova(m)
summary(m)
n<-glht(m, linfct=mcp(Clade ="Tukey"))
summary(n)

#R
m<-gls(r2rat~Clade, correlation=corPagel(1, tree, form = ~Species), data=de)
anova(m)
summary(m)
n<-glht(m, linfct=mcp(Clade ="Tukey"))
summary(n)


# Phylogenetic Signal in SF, SL, R2
sf <- de$SF_speed_slope
names(sf) <- de$Row.names
phylosig(tree, sf, test=TRUE, nsim=10000)

sl <- de$SL_speed_slope
names(sl) <- de$Row.names
phylosig(tree, sl, test=TRUE, nsim=10000)

r2 <- de$log.R2_ratio.
names(r2) <- de$Row.names
phylosig(tree, r2, test=TRUE, nsim=10000)


#CLADE PLOTS
fig1<-ggplot(de)+geom_boxplot(mapping=aes(x=Clade, y=slcoef, fill=Clade)) + theme_classic()+
  theme(text=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8))+
  xlab("")+
  scale_x_discrete(breaks=waiver(), labels=c("Amph.", "Bird", "Croc.", "Liza.", "Mamm.", "Turt."))+
  ylab("SL - Speed Slope")+
  theme(legend.position = "none")
fig2<-ggplot(de)+geom_boxplot(mapping=aes(x=Clade, y=sfcoef, fill=Clade)) + theme_classic()+
  theme(text=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8))+
  xlab("")+
  scale_x_discrete(breaks=waiver(), labels=c("Amph.", "Bird", "Croc.", "Liza.", "Mamm.", "Turt."))+
  ylab("SF - Speed Slope")+
  theme(legend.position = "none")
fig3<-ggplot(de)+geom_boxplot(mapping=aes(x=Clade, y=r2rat, fill=Clade)) + theme_classic()+
  theme(text=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8))+
  scale_x_discrete(breaks=waiver(), labels=c("Amph.", "Bird", "Croc.", "Liza.", "Mamm.", "Turt."))+
  xlab("")+
  ylab(expression(log~R^{"2"}~Ratio))+
  theme(legend.position = "none")+
  ylim(c(-5,5))

levels(de_mammal$Primate) <- c("", "Non-Primate Mammal", "Primate")
fig4<-ggplot(de_mammal)+geom_boxplot(mapping=aes(x=Primate, y=slcoef, fill=Primate)) + theme_classic()+
  theme(text=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8))+
  xlab("")+
  ylab("SL - Speed Slope")+
  theme(legend.position = "none")
fig5<-ggplot(de_mammal)+geom_boxplot(mapping=aes(x=Primate, y=sfcoef, fill=Primate)) + theme_classic()+
  theme(text=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8))+
  xlab("")+
  ylab("SF - Speed Slope")+
  theme(legend.position = "none")  
fig6<-ggplot(de_mammal)+geom_boxplot(mapping=aes(x=Primate, y=r2rat, fill=Primate)) +   theme_classic()+
  theme(text=element_text(size=8), axis.text.x=element_text(size=8), axis.text.y=element_text(size=8))+
  xlab("")+
  ylab(expression(log~R^{"2"}~Ratio))+
  theme(legend.position = "none")+
  ylim(c(-5,5))

plots<-ggarrange(fig1, fig4, fig2, fig5, fig3, fig6, nrow=3, ncol=2, labels="AUTO")

